@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2023 Statnet Commons
+#  Copyright 2003-2024 Statnet Commons
 ################################################################################
 
 #' Auxiliary for Controlling ERGM Simulation
@@ -15,8 +15,8 @@
 #' `control.simulate.formula.ergm` are all aliases for the same
 #' function.
 #' 
-#' This function is only used within a call to the \code{\link{simulate}}
-#' function.  See the \code{usage} section in \code{\link{simulate.ergm}} for
+#' This function is only used within a call to the ERGM [simulate()]
+#' function.  See the Usage section in [simulate.ergm()] for
 #' details.
 #'
 #' @templateVar MCMCType MCMC
@@ -49,17 +49,17 @@
 #' @template control_MCMC_packagenames
 #' @template control_dots
 #' @return A list with arguments as components.
-#' @seealso \code{\link{simulate.ergm}}, \code{\link{simulate.formula}}.
-#' \code{\link{control.ergm}} performs a similar function for
-#' \code{\link{ergm}}; \code{\link{control.gof}} performs a similar function
-#' for \code{\link{gof}}.
+#' @seealso [simulate.ergm()], [simulate.formula()].
+#' [control.ergm()] performs a similar function for
+#' [ergm()]; [control.gof()] performs a similar function
+#' for [gof()].
 #'
 #' @name control.simulate.ergm
 #' @keywords models
 #' @export control.simulate.formula.ergm
 control.simulate.formula.ergm<-function(MCMC.burnin=MCMC.interval*16,
                                         MCMC.interval=1024,
-                                        MCMC.prop=trim_env(~sparse),
+                                        MCMC.prop=trim_env(~sparse + .triadic),
                                         MCMC.prop.weights="default",
                                         MCMC.prop.args=list(),
 
