@@ -5,14 +5,10 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2023 Statnet Commons
+#  Copyright 2003-2024 Statnet Commons
 ################################################################################
-#' Fit, Simulate and Diagnose Exponential-Family Models for Networks
-#' 
-#' \code{\link[=ergm-package]{ergm}} \insertCite{HuHa08e,KrHu23e}{ergm} is a collection of functions to plot, fit,
-#' diagnose, and simulate from exponential-family random graph models (ERGMs).
-#' For a list of functions type: \code{help(package='ergm')}
-#' 
+#' @details \insertNoCite{HuHa08e,KrHu23e}{ergm}
+#'
 #' For a complete list of the functions, use \code{library(help="ergm")} or
 #' read the rest of the manual. For a simple demonstration, use
 #' \code{demo(packages="ergm")}.
@@ -26,8 +22,8 @@
 #' Recent advances in the statistical modeling of random networks have had an
 #' impact on the empirical study of social networks. Statistical exponential
 #' family models (Strauss and Ikeda 1990) are a generalization of the Markov
-#' random network models introduced by Frank and Strauss (1986), which in turn
-#' derived from developments in spatial statistics (Besag, 1974). These models
+#' random network models introduced by \insertCite{FrSt86m;textual}{ergm}, which in turn
+#' derived from developments in spatial statistics \insertCite{Be74s}{ergm}. These models
 #' recognize the complex dependencies within relational data structures.  To
 #' date, the use of stochastic network models for networks has been limited by
 #' three interrelated factors: the complexity of realistic models, the lack of
@@ -36,16 +32,16 @@
 #' 
 #' This manual introduces software tools for the representation, visualization,
 #' and analysis of network data that address each of these previous
-#' shortcomings.  The package relies on the \code{\link[network]{network}}
+#' shortcomings.  The package relies on the [`network`]
 #' package which allows networks to be represented in . The
-#' \code{\link[=ergm-package]{ergm}} package implements maximum likelihood
+#' \CRANpkg{ergm} package implements maximum likelihood
 #' estimates of ERGMs to be calculated using Markov Chain Monte Carlo (via
-#' \code{\link{ergm}}). The package also provides tools for simulating networks
-#' (via \code{\link{simulate.ergm}}) and assessing model goodness-of-fit (see
-#' \code{\link{mcmc.diagnostics}} and \code{\link{gof.ergm}}).
+#' [ergm()]). The package also provides tools for simulating networks
+#' (via [simulate.ergm()]) and assessing model goodness-of-fit (see
+#' [mcmc.diagnostics()] and [gof.ergm()]).
 #'
 #' A number of Statnet Project packages extend and enhance
-#' \pkg{\link[=ergm-package]{ergm}}. These include
+#' \CRANpkg{ergm}. These include
 #' \CRANpkg{tergm} (Temporal ERGM), which provides
 #' extensions for modeling evolution of networks over time;
 #' \CRANpkg{ergm.count}, which facilitates
@@ -55,7 +51,7 @@
 #' allows users to implement their own ERGM terms.
 #' 
 #' For detailed information on how to download and install the software, go to
-#' the \code{\link[=ergm-package]{ergm}} website: \url{https://statnet.org}. A
+#' the \CRANpkg{ergm} website: \url{https://statnet.org}. A
 #' tutorial, support newsgroup, references and links to further resources are
 #' provided there.
 #'
@@ -63,19 +59,9 @@
 #'   [`ergmHint`], and [`ergmProposal`] for indices of model
 #'   specification and estimation components visible to the \CRANpkg{ergm}'s API at any given time.
 #' 
-#' @name ergm-package
-#' @docType package
-#' @author Mark S. Handcock \email{handcock@@stat.ucla.edu},\cr David R. Hunter
-#' \email{dhunter@@stat.psu.edu},\cr Carter T. Butts
-#' \email{buttsc@@uci.edu},\cr Steven M. Goodreau
-#' \email{goodreau@@u.washington.edu},\cr Pavel N. Krivitsky
-#' \email{pavel@@statnet.org}, and\cr Martina Morris
-#' \email{morrism@@u.washington.edu}
-#' 
-#' Maintainer: Pavel N. Krivitsky \email{pavel@@statnet.org}
 #' @references \insertAllCited{}
 #'
-#' Admiraal R, Handcock MS (2007).  \pkg{networksis}: Simulate
+#' Admiraal R, Handcock MS (2007).  \CRANpkg{networksis}: Simulate
 #' bipartite graphs with fixed marginals through sequential importance
 #' sampling.  Statnet Project, Seattle, WA.  Version 1,
 #' \url{https://statnet.org}.
@@ -85,30 +71,23 @@
 #' \pkg{rSoNIA}.  \emph{Journal of Statistical Software}, 24(7).
 #' \doi{10.18637/jss.v024.i07}
 #' 
-#' Besag, J., 1974, Spatial interaction and the statistical analysis of lattice
-#' systems (with discussion), \emph{Journal of the Royal Statistical Society,
-#' B}, 36, 192-236.
-#' 
 #' Boer P, Huisman M, Snijders T, Zeggelink E (2003).  StOCNET: an open
 #' software system for the advanced statistical analysis of social networks.
 #' Groningen: ProGAMMA / ICS, version 1.4 edition.
 #' 
-#' Butts CT (2007).  \pkg{sna}: Tools for Social Network Analysis.  R package
+#' Butts CT (2007).  \CRANpkg{sna}: Tools for Social Network Analysis.  R package
 #' version 2.3-2. \url{https://cran.r-project.org/package=sna}
 #' 
-#' Butts CT (2008).  \pkg{network}: A Package for Managing Relational Data in .
+#' Butts CT (2008).  \CRANpkg{network}: A Package for Managing Relational Data in .
 #' \emph{Journal of Statistical Software}, 24(2).
 #' \doi{10.18637/jss.v024.i02}
 #' 
-#' Butts C (2015). \pkg{network}: Classes for Relational Data. The Statnet
+#' Butts C (2015). \CRANpkg{network}: Classes for Relational Data. The Statnet
 #' Project (\url{https://statnet.org}). R package version 1.12.0,
 #' \url{https://cran.r-project.org/package=network}.
 #' 
-#' Frank, O., and Strauss, D.(1986). Markov graphs. \emph{Journal of the
-#' American Statistical Association}, 81, 832-842.
-#' 
 #' Goodreau SM, Handcock MS, Hunter DR, Butts CT, Morris M (2008a).  A
-#' \pkg{statnet} Tutorial.  \emph{Journal of Statistical Software}, 24(8).
+#' \CRANpkg{statnet} Tutorial.  \emph{Journal of Statistical Software}, 24(8).
 #' \doi{10.18637/jss.v024.i08}
 #' 
 #' Goodreau SM, Kitts J, Morris M (2008b).  Birds of a Feather, or Friend of a
@@ -120,29 +99,19 @@
 #' University of Washington.
 #' \url{https://csss.uw.edu/research/working-papers/assessing-degeneracy-statistical-models-social-networks}
 #' 
-#' Handcock MS (2003b).  \pkg{degreenet}: Models for Skewed Count Distributions
+#' Handcock MS (2003b).  \CRANpkg{degreenet}: Models for Skewed Count Distributions
 #' Relevant to Networks.  Statnet Project, Seattle, WA.  Version 1.0,
 #' \url{https://statnet.org}.
 #' 
-#' Handcock MS, Hunter DR, Butts CT, Goodreau SM, Morris M (2003a).
-#' \pkg{ergm}: A Package to Fit, Simulate and Diagnose Exponential-Family
-#' Models for Networks.  Statnet Project, Seattle, WA.  Version 3,
-#' \url{https://statnet.org}.
-#' 
 #' Handcock MS, Hunter DR, Butts CT, Goodreau SM, Morris M (2003b).
-#' \pkg{statnet}: Software Tools for the Statistical Modeling of Network Data.
+#' \CRANpkg{statnet}: Software Tools for the Statistical Modeling of Network Data.
 #' Statnet Project, Seattle, WA.  Version 3, \url{https://statnet.org}.
 #' 
 #' Hunter, D. R. and Handcock, M. S. (2006) Inference in curved exponential
 #' family models for networks, \emph{Journal of Computational and Graphical
 #' Statistics}, 15: 565-583
 #' 
-#' Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b).
-#' \pkg{ergm}: A Package to Fit, Simulate and Diagnose Exponential-Family
-#' Models for Networks.  \emph{Journal of Statistical Software}, 24(3).
-#' \doi{10.18637/jss.v024.i03}
-#' 
-#' Krivitsky PN, Handcock MS (2007).  \pkg{latentnet}: Latent position and
+#' Krivitsky PN, Handcock MS (2007).  \CRANpkg{latentnet}: Latent position and
 #' cluster models for statistical networks.  Seattle, WA.  Version 2,
 #' \url{https://statnet.org}.
 #' 
@@ -158,15 +127,14 @@
 #' Strauss, D., and Ikeda, M.(1990). Pseudolikelihood estimation for social
 #' networks. \emph{Journal of the American Statistical Association}, 85,
 #' 204-212.
-#' @keywords package models
-NULL
+#' @keywords models internal
+"_PACKAGE"
 
 
 #' Terms used in Exponential Family Random Graph Models
 #'
 #' @name ergmTerm
 #' @aliases ergm-terms ergm.terms terms-ergm terms.ergm InitErgmTerm InitErgmWtTerm
-#' @docType package
 #' @description This page explains how to specify the network statistics \eqn{g(y)} to functions in the [`ergm`][ergm-package] package and packages that extend it. It also provides an indexed list of the possible terms (and hence network statistics) visible to the \CRANpkg{ergm} API. Terms can also be searched via [`search.ergmTerms`], and help for an individual term can be obtained with `ergmTerm?<term>` or `help("<term>-ergmTerm")`.
 #'
 #' @section Specifying models:
@@ -405,7 +373,6 @@ NULL
 #'
 #' @name ergmConstraint
 #' @aliases ergm-constraints constraints-ergm ergm.constraints constraints.ergm
-#' @docType package
 #' @description This page describes how to specify the constraints on the network sample space (the set of possible networks \eqn{Y}, the set of networks \eqn{y} for which \eqn{h(y)>0}) and sometimes the baseline weights \eqn{h(y)} to functions in the [`ergm`][ergm-package]
 #' package. It also provides an indexed list of the constraints visible to the \CRANpkg{ergm}'s API. Constraints can also be searched via [`search.ergmConstraints`], and help for an individual constraint can be obtained with `ergmConstraint?<constraint>` or `help("<constraint>-ergmConstraint")`.
 #'
@@ -485,7 +452,7 @@ NULL
 #'
 #' @references
 #' - Goodreau SM, Handcock MS, Hunter DR, Butts CT, Morris M (2008a).  A
-#' \pkg{statnet} Tutorial. *Journal of Statistical Software*, 24(8).
+#' \CRANpkg{statnet} Tutorial. *Journal of Statistical Software*, 24(8).
 #' \doi{10.18637/jss.v024.i08}
 #'
 #' - Hunter, D. R. and Handcock, M. S. (2006) *Inference in curved
@@ -493,7 +460,7 @@ NULL
 #' Graphical Statistics.
 #'
 #' - Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b).
-#' \pkg{ergm}: A Package to Fit, Simulate and Diagnose Exponential-Family
+#' \CRANpkg{ergm}: A Package to Fit, Simulate and Diagnose Exponential-Family
 #' Models for Networks.  *Journal of Statistical Software*, 24(3).
 #' \doi{10.18637/jss.v024.i03}
 #'
@@ -516,7 +483,6 @@ NULL
 #'
 #' @name ergmHint
 #' @aliases ergm-hints hints-ergm ergm.hints hints.ergm hints
-#' @docType package
 #' @description This page describes how to provide to the
 #'   \CRANpkg{ergm}'s MCMC algorithms information about the sample space. Hints can also be searched via [`search.ergmHints`], and help for an individual hint can be obtained with `ergmHint?<hint>` or `help("<hint>-ergmHint")`.
 #'
@@ -564,7 +530,7 @@ NULL
 #' 
 #' @references
 #' - Goodreau SM, Handcock MS, Hunter DR, Butts CT, Morris M (2008a).  A
-#' \pkg{statnet} Tutorial. *Journal of Statistical Software*, 24(8).
+#' \CRANpkg{statnet} Tutorial. *Journal of Statistical Software*, 24(8).
 #' \doi{10.18637/jss.v024.i08}
 #' 
 #' - Hunter, D. R. and Handcock, M. S. (2006) *Inference in curved
@@ -572,7 +538,7 @@ NULL
 #' Graphical Statistics.
 #' 
 #' - Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b).
-#' \pkg{ergm}: A Package to Fit, Simulate and Diagnose Exponential-Family
+#' \CRANpkg{ergm}: A Package to Fit, Simulate and Diagnose Exponential-Family
 #' Models for Networks.  *Journal of Statistical Software*, 24(3).
 #' \doi{10.18637/jss.v024.i03}
 #' 
@@ -596,7 +562,6 @@ NULL
 #'
 #' @name ergmReference
 #' @aliases ergm-references references-ergm ergm.references references.ergm
-#' @docType package
 #' @description This page describes how to specify the reference measures (baseline distributions)
 #' (the set of possible networks \eqn{Y} and the baseline weights \eqn{h(y)} to functions in the [`ergm`][ergm-package]
 #' package. It also provides an indexed list of the references visible to the \CRANpkg{ergm}'s API. References can also be searched via [search.ergmReferences()], and help for an individual reference can be obtained with `ergmReference?<reference>` or `help("<reference>-ergmReference")`.
@@ -628,7 +593,7 @@ NULL
 #' @seealso [`ergm`][ergm-package], [`network`], \CRANpkg{sna}, [`summary.ergm`], [`print.ergm`], `\%v\%`, `\%n\%`
 #' 
 #' @references
-#' - Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b). \pkg{ergm}:
+#' - Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b). \CRANpkg{ergm}:
 #' A Package to Fit, Simulate and Diagnose Exponential-Family Models for
 #' Networks. *Journal of Statistical Software*, 24(3).
 #' \doi{10.18637/jss.v024.i03}
@@ -643,18 +608,32 @@ NULL
 #' Metropolis-Hastings Proposal Methods for ERGM MCMC
 #'
 #' @name ergmProposal
-#' @aliases ergm-proposals proposals-ergm ergm.proposals proposals.ergm InitErgmProposal InitWtErgmProposal
-#' @docType package
-#' @description [`ergm`]  uses a Metropolis-Hastings (MH) algorithm to control the behavior of the Markov Chain
-#'   Monte Carlo (MCMC) for sampling networks.  The MCMC chain is intended to step around the sample space of
-#'   possible networks, selecting a network at regular intervals to evaluate the statistics in the model.  For
-#'   each MCMC step, \eqn{n} (\eqn{n=1} in the simple case) toggles are proposed to change the dyad(s) to the
-#'   opposite value. The probability of accepting the proposed change is determined by the MH acceptance ratio.
-#'   The role of the different MH methods implemented in \code{\link{ergm}} is to vary how the sets of dyads are
-#'   selected for toggle proposals.  This is used in some cases to improve the performance (speed and mixing) of
-#'   the algorithm, and in other cases to constrain the sample space. Proposals can also be searched via [`search.ergmProposals`], and help for an individual proposal can be obtained with `ergmProposal?<proposal>` or `help("<proposal>-ergmProposal")`.
+#' @aliases ergm-proposals proposals-ergm ergm.proposals
+#'   proposals.ergm InitErgmProposal InitWtErgmProposal
+#' @description This page describes the low-level Metropolis--Hastings
+#'   (MH) proposal algorithms. They are rarely invoked directly by the
+#'   user but are rather selected based on the provided [sample space
+#'   constraints][ergmConstraint] and [hints about the network
+#'   process][ergmHint].  They can also be searched via
+#'   [`search.ergmProposals`], and help for an individual proposal can
+#'   be obtained with `ergmProposal?<proposal>` or
+#'   `help("<proposal>-ergmProposal")`.
 #'
-#' @section Implemented proposals for ergm models:
+#' @details [`ergm`] uses a Metropolis-Hastings (MH) algorithm to
+#'   control the behavior of the Markov Chain Monte Carlo (MCMC) for
+#'   sampling networks.  The MCMC chain is intended to step around the
+#'   sample space of possible networks, generating a network at
+#'   regular intervals to evaluate the statistics in the model.  For
+#'   each MCMC step, one or more toggles are proposed to change the
+#'   dyads to the opposite value. The probability of accepting the
+#'   proposed change is determined by the MH acceptance ratio.  The
+#'   role of the different MH methods implemented in
+#'   [ergm()] is to vary how the sets of dyads are selected
+#'   for toggle proposals.  This is used in some cases to improve the
+#'   performance (speed and mixing) of the algorithm, and in other
+#'   cases to constrain the sample space.
+#'
+#' @section Proposals available to the package:
 #'
 #' \ergmCSS
 #'
@@ -662,16 +641,18 @@ NULL
 #' \if{text}{\Sexpr[results=rd,stage=render]{ergm:::.formatProposalsText(ergm:::.buildProposalsList(), keepProposal=TRUE)}}
 #' \if{latex}{\Sexpr[results=rd,stage=render]{ergm:::.formatProposalsLatex(ergm:::.buildProposalsList(), keepProposal=TRUE)}}
 #'
-#' @seealso [`ergm`][ergm-package] package, [`ergm`], [`ergmConstraint`], [`ergm_proposal`]
+#' Note that [`.dyads`][.dyads-ergmConstraint] is a meta-constraint, indicating that the proposal supports an arbitrary dyad-level constraint combination.
+#'
+#' @seealso [`ergm`][ergm-package] package, [`ergm`], [`ergmConstraint`], [`ergmHint`], [`ergm_proposal`]
 #'
 #' @references
-#' - Goodreau SM, Handcock MS, Hunter DR, Butts CT, Morris M (2008a).  A \pkg{statnet} Tutorial.
+#' - Goodreau SM, Handcock MS, Hunter DR, Butts CT, Morris M (2008a).  A \CRANpkg{statnet} Tutorial.
 #' *Journal of Statistical Software*, 24(8). \doi{10.18637/jss.v024.i08}
 #'
 #' - Hunter, D. R. and Handcock, M. S. (2006) Inference in curved exponential family models for networks.
 #' *Journal of Computational and Graphical Statistics*.
 #'
-#' - Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b). \pkg{ergm}:
+#' - Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b). \CRANpkg{ergm}:
 #' A Package to Fit, Simulate and Diagnose Exponential-Family Models for
 #' Networks. *Journal of Statistical Software*, 24(3).
 #' \doi{10.18637/jss.v024.i03}
