@@ -5,36 +5,36 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2023 Statnet Commons
+#  Copyright 2003-2024 Statnet Commons
 ################################################################################
 
 #' Bridge sampling to evaluate ERGM log-likelihoods and log-likelihood ratios
 #' 
 #' \code{ergm.bridge.llr} uses bridge sampling with geometric spacing to
 #' estimate the difference between the log-likelihoods of two parameter vectors
-#' for an ERGM via repeated calls to \code{\link{simulate.formula.ergm}}.
+#' for an ERGM via repeated calls to [simulate.formula.ergm()].
 #' 
 #' 
 #' 
-#' @param object A model formula. See \code{\link{ergm}} for details.
+#' @param object A model formula. See [ergm()] for details.
 #' @template response
 #' @param constraints,obs.constraints One-sided formulas specifying
 #'   one or more constraints on the support of the distribution of the
 #'   networks being simulated and on the observation process
 #'   respectively. See the documentation for similar arguments for
-#'   \code{\link{ergm}} for more information.
+#'   [ergm()] for more information.
 #' @param reference {A one-sided formula specifying the reference
 #'   measure (\eqn{h(y)}) to be used.  (Defaults to
 #'   \code{~Bernoulli}.)}
 #' @param target.stats {A vector of sufficient statistics to be used
 #'   in place of those of the network in the formula.}
 #' @param from,to The initial and final parameter vectors.
-#' @param basis An optional \code{\link[network]{network}} object to
+#' @param basis An optional [`network`] object to
 #'   start the Markov chain.  If omitted, the default is the
 #'   left-hand-side of the \code{object}.
 #' @template verbose
 #' @param \dots Further arguments to \code{ergm.bridge.llr} and
-#'   \code{\link{simulate.formula.ergm}}.
+#'   [simulate.formula.ergm()].
 #' @param llronly Logical: If TRUE, only the estiamted log-ratio will
 #'   be returned by `ergm.bridge.llr`.
 #'
@@ -71,7 +71,7 @@
 #'
 #'   \item{Dtheta.Du}{The gradient vector of the parameter values with
 #'   respect to position of the bridge.}
-#' @seealso \code{\link{simulate.formula.ergm}}
+#' @seealso [simulate.formula.ergm()]
 #' @references Hunter, D. R. and Handcock, M. S. (2006)
 #'   \emph{Inference in curved exponential family models for
 #'   networks}, Journal of Computational and Graphical Statistics.
@@ -153,7 +153,7 @@ ergm.bridge.llr<-function(object, response=NULL, reference=~Bernoulli, constrain
   }
 
   ## Miscellaneous settings
-  Dtheta.Du <- (to-from)[!state[[1]]$model$etamap$offsettheta]
+  Dtheta.Du <- ifelse(mapply(identical, to, from), 0, to - from)[!state[[1]]$model$etamap$offsettheta]
 
   ## Handle target statistics, if passed.
   if(!is.null(target.stats)){
@@ -339,7 +339,7 @@ ergm.bridge.dindstart.llk<-function(object, response=NULL, constraints=~., coef,
 
   message("Fitting the dyad-independent submodel...")
   if(is.null(coef.dind)){
-    ergm.dind<-suppressMessages(suppressWarnings(ergm(dind,basis=nw,estimate="MPLE",constraints=constraints,obs.constraints=obs.constraints,eval.loglik=FALSE,control=control.ergm(drop=FALSE, term.options=control$term.options, MPLE.max.dyad.types=control$MPLE.max.dyad.types), offset.coef = offset.dind)))
+    ergm.dind <- suppressMessages(suppressWarnings(ergm(dind, basis=nw, estimate="MPLE", constraints=constraints, obs.constraints=obs.constraints, eval.loglik=FALSE, control=control.ergm(drop=control$drop, term.options=control$term.options, MPLE.check=FALSE, MPLE.max.dyad.types=control$MPLE.max.dyad.types), offset.coef=offset.dind)))
     etamap.dind <- ergm.dind$etamap
     stats.dind <- ergm.dind$nw.stats
 
@@ -347,7 +347,7 @@ ergm.bridge.dindstart.llk<-function(object, response=NULL, constraints=~., coef,
     eta.dind <- ifelse(is.na(eta.dind),0,eta.dind)
     llk.dind <- ergm.dind$mple.lik
   }else{
-    mple.dind <- suppressMessages(suppressWarnings(ergmMPLE(dind, output="matrix", constraints=constraints,obs.constraints=obs.constraints, control=control.ergm(drop=FALSE, term.options=control$term.options, MPLE.max.dyad.types=control$MPLE.max.dyad.types))))
+    mple.dind <- suppressMessages(suppressWarnings(ergmMPLE(dind, output="matrix", constraints=constraints,obs.constraints=obs.constraints, control=control.ergm(drop=control$drop, term.options=control$term.options, MPLE.max.dyad.types=control$MPLE.max.dyad.types))))
     etamap.dind <- attr(ergm.dind, "etamap")
     stats.dind <- summary(dind, basis=nw)
 
