@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2023 Statnet Commons
+#  Copyright 2003-2024 Statnet Commons
 ################################################################################
 ###################################################################
 ## This file has utilities whose primary purpose is examining or ##
@@ -38,14 +38,18 @@ is.dyad.independent<-function(object,...) UseMethod("is.dyad.independent")
 is.dyad.independent.NULL <- function(object, ...) TRUE # By convention.
 
 #' @describeIn ergm_model Tests whether the model is dyad-independent.
+#' @param ignore_aux A flag to specify whether a dyad-dependent
+#'   auxiliary should make the model dyad-dependent or should be
+#'   ignored.
 #' @export
-is.dyad.independent.ergm_model <- function(object, ...){
-  ! any(sapply(object$terms, function(term) is.null(term$dependence) || term$dependence))
+is.dyad.independent.ergm_model <- function(object, ..., ignore_aux=TRUE){
+  ## NB: Auxiliaries (i.e., terms without statistics) do not affect dyadic dependence.
+  ! any(sapply(object$terms, function(term) (!ignore_aux || length(term$coef.names)) && (is.null(term$dependence) || term$dependence)))
 }
 
 #' @rdname is.dyad.independent
 #' @template response
-#' @param basis See \code{\link{ergm}}.
+#' @param basis See [ergm()].
 #' @export
 is.dyad.independent.formula<-function(object,response=NULL,basis=NULL,...){
   # If basis is not null, replace network in formula by basis.
@@ -62,7 +66,7 @@ is.dyad.independent.formula<-function(object,response=NULL,basis=NULL,...){
 
   ergm_preprocess_response(nw, response)
   m<-ergm_model(object, nw, ...)
-  is.dyad.independent(m)
+  is.dyad.independent(m, ...)
 }
 
 #' @rdname is.dyad.independent
