@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2023 Statnet Commons
+ *  Copyright 2003-2024 Statnet Commons
  */
 
 #ifndef _ERGM_STORAGE_H_
@@ -22,7 +22,7 @@
 // 2. Allocates a vector of `nmemb` elements of type `stored_type`.
 // 3. Saves its pointer to private storage.
 // 4. Also assigns its pointer to store_into.
-#define ALLOC_STORAGE(nmemb, stored_type, store_into) stored_type *store_into = (stored_type *) (STORAGE = Calloc(nmemb, stored_type));
+#define ALLOC_STORAGE(nmemb, stored_type, store_into) stored_type *store_into = (stored_type *) (STORAGE = R_Calloc(nmemb, stored_type));
 
 // 1. Declares a stored_type *store_into.
 // 2. Assigns pointer to private storage to store_into.
@@ -40,7 +40,7 @@
 // 2. Allocates a vector of `nmemb` elements of type `stored_type`.
 // 3. Saves its pointer to its assigned public storage slot.
 // 4. Also assigns its pointer to store_into.
-#define ALLOC_AUX_STORAGE(nmemb, stored_type, store_into) stored_type *store_into = (stored_type *) (AUX_STORAGE = Calloc(nmemb, stored_type));
+#define ALLOC_AUX_STORAGE(nmemb, stored_type, store_into) stored_type *store_into = (stored_type *) (AUX_STORAGE = R_Calloc(nmemb, stored_type));
 // 1. Declares a stored_type *store_into.
 // 2. Assigns pointer to its assigned auxiliary storage slot (or, for a statistic, its first requested auxiliary) to store_into.
 #define GET_AUX_STORAGE(stored_type, store_into) stored_type *store_into = AUX_STORAGE;
@@ -75,7 +75,7 @@
   store_into--; /* Shift the pointer array by -1. */			\
   AUX_STORAGE = store_into; /* This is needed to make sure the pointer array itself is updated. */
 
-/* Free a sociomatrix in auxiliary storage. */
+/* R_Free a sociomatrix in auxiliary storage. */
 /* If we hadn't shifted the pointers by -1, this would not have been
    necessary. We need to shift the array back into place so that it's
    automatically deallocated. */
