@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2023 Statnet Commons
+#  Copyright 2003-2024 Statnet Commons
 ################################################################################
 n<-500
 base.net <- network.initialize(n=n,directed=FALSE)
@@ -33,8 +33,9 @@ test_that("simulating from the MPLE target statistics fit", {
 
 test_that("MPLE with no estimable parameters fails at a later stage", {
   net1<-network.initialize(5578,directed=FALSE)
-  expect_error(expect_warning(
+  expect_error(expect_warning(expect_warning(
     ergm(net1~triangles,target.stats=c(1)),
+    "^The MPLE does not exist!.*"),
     "^Model statistics .*triangle.* are not varying..*"),
     "^Number of edges in a simulated network exceeds that in the observed by a factor of more than.*")
 })
