@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2023 Statnet Commons
+#  Copyright 2003-2024 Statnet Commons
 ################################################################################
 data(florentine)
 
@@ -149,7 +149,7 @@ test_that("Binary Label() summary", {
   )
 })
 
-test_that("Binary Label() estimation and offsets in submodels", {
+test_that("Binary Label() estimation, offsets, and curved terms", {
   expect_equal(
     coef(ergm(flomarriage ~ Label(~edges+offset(absdiff("wealth")), "abc"), offset.coef=-.5)),
     coef(ergm(flomarriage ~ edges+offset(absdiff("wealth")), offset.coef=-.5)), ignore_attr=TRUE
@@ -159,6 +159,31 @@ test_that("Binary Label() estimation and offsets in submodels", {
     coef(ergm(flomarriage ~ Label(~edges+offset(gwesp), "abc"), offset.coef=c(-.5,1), estimate="MPLE")),
     coef(ergm(flomarriage ~ edges+offset(gwesp), offset.coef=c(-.5,1), estimate="MPLE")), ignore_attr=TRUE
   )
+
+  ## list label
+  ca <- c("abc", paste0("def", 1:14))
+  cu <- c("abc", "ijk", "lmn")
+  f <- flomarriage ~ Label(~edges+gwesp, list(cu, ca), "replace")
+  expect_named(coef(ergm(f, estimate="MPLE")), cu)
+  expect_named(summary(f), ca)
+
+  ## list label with omitted vector
+  f <- flomarriage ~ Label(~edges+gwesp, list(cu, NULL), "replace")
+  f0 <- flomarriage ~edges+gwesp
+  expect_named(coef(ergm(f, estimate="MPLE")), cu)
+  expect_named(summary(f), c("abc", names(summary(f0))[-1]))
+
+  f <- flomarriage ~ Label(~edges+gwesp, list(NA, ca), "replace")
+  f0 <- flomarriage ~edges+gwesp
+  expect_named(coef(ergm(f, estimate="MPLE")), param_names(ergm(f, estimate="MPLE")))
+  expect_named(summary(f), ca)
+
+  ## mapper label
+  f <- flomarriage ~ Label(~edges+gwesp, ~gsub("[.#]","!",.))
+  expect_named(coef(ergm(f, estimate="MPLE")),
+               c("edges", "gwesp", "gwesp!decay"))
+  expect_named(summary(f), c("edges", paste0("esp!", 1:14)))
+
 })
 
 
