@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2023 Statnet Commons
+#  Copyright 2003-2024 Statnet Commons
 ################################################################################
 
 test_that("BDStratTNT works with undirected unipartite networks and bd/blocks only", {
@@ -1265,7 +1265,7 @@ test_that("BDStratTNT handles undirected heterogeneous degree bound saturation c
                   constraints = ~bd(attr = bd_attr, maxout = maxout)
                                  + blocks(attr = ~blocks_attr, levels2 = levels2)
                                  + strat(attr = ~strat_attr, pmat = pmat),
-                  control = list(MCMC.burnin = 1e5))
+                  control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws)
@@ -1279,7 +1279,7 @@ test_that("BDStratTNT handles undirected heterogeneous degree bound saturation c
                    constraints = ~bd(attr = bd_attr, maxout = maxout)
                                   + blocks(attr = ~blocks_attr, levels2 = levels2)
                                   + strat(attr = ~strat_attr, pmat = pmat),
-                   control = list(MCMC.burnin = 1e5))
+                   control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws2 ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws2)
@@ -1310,7 +1310,7 @@ test_that("BDStratTNT handles directed heterogeneous degree bound saturation cor
                   constraints = ~bd(attr = bd_attr, maxout = maxout, maxin = maxin)
                                  + blocks(attr = ~blocks_attr, levels2 = levels2)
                                  + strat(attr = ~strat_attr, pmat = pmat),
-                  control = list(MCMC.burnin = 1e5))
+                  control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws)
@@ -1327,7 +1327,7 @@ test_that("BDStratTNT handles directed heterogeneous degree bound saturation cor
                    constraints = ~bd(attr = bd_attr, maxout = maxout, maxin = maxin)
                                   + blocks(attr = ~blocks_attr, levels2 = levels2)
                                   + strat(attr = ~strat_attr, pmat = pmat),
-                   control = list(MCMC.burnin = 1e5))
+                   control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws2 ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws2)
@@ -1361,7 +1361,7 @@ test_that("BDStratTNT handles bipartite heterogeneous degree bound saturation co
                   constraints = ~bd(attr = bd_attr, maxout = maxout)
                                  + blocks(attr = ~blocks_attr, levels2 = levels2)
                                  + strat(attr = ~strat_attr, pmat = pmat),
-                  control = list(MCMC.burnin = 1e5))
+                  control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws)
@@ -1375,7 +1375,7 @@ test_that("BDStratTNT handles bipartite heterogeneous degree bound saturation co
                    constraints = ~bd(attr = bd_attr, maxout = maxout)
                                   + blocks(attr = ~blocks_attr, levels2 = levels2)
                                   + strat(attr = ~strat_attr, pmat = pmat),
-                   control = list(MCMC.burnin = 1e5))
+                   control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws2 ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws2)
@@ -1403,7 +1403,7 @@ test_that("BDStratTNT handles undirected homogeneous degree bound saturation cor
                   constraints = ~bd(maxout = maxout)
                                  + blocks(attr = ~blocks_attr, levels2 = levels2)
                                  + strat(attr = ~strat_attr, pmat = pmat),
-                  control = list(MCMC.burnin = 1e5))
+                  control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws)
@@ -1416,7 +1416,7 @@ test_that("BDStratTNT handles undirected homogeneous degree bound saturation cor
                    constraints = ~bd(maxout = maxout)
                                   + blocks(attr = ~blocks_attr, levels2 = levels2)
                                   + strat(attr = ~strat_attr, pmat = pmat),
-                   control = list(MCMC.burnin = 1e5))
+                   control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws2 ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws2)
@@ -1443,7 +1443,7 @@ test_that("BDStratTNT handles directed homogeneous degree bound saturation corre
                   constraints = ~bd(maxout = maxout, maxin = maxin)
                                  + blocks(attr = ~blocks_attr, levels2 = levels2)
                                  + strat(attr = ~strat_attr, pmat = pmat),
-                  control = list(MCMC.burnin = 1e5))
+                  control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws)
@@ -1458,7 +1458,7 @@ test_that("BDStratTNT handles directed homogeneous degree bound saturation corre
                    constraints = ~bd(maxout = maxout, maxin = maxin)
                                   + blocks(attr = ~blocks_attr, levels2 = levels2)
                                   + strat(attr = ~strat_attr, pmat = pmat),
-                   control = list(MCMC.burnin = 1e5))
+                   control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws2 ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws2)
@@ -1487,7 +1487,7 @@ test_that("BDStratTNT handles bipartite homogeneous degree bound saturation corr
                   constraints = ~bd(maxout = maxout)
                                  + blocks(attr = ~blocks_attr, levels2 = levels2)
                                  + strat(attr = ~strat_attr, pmat = pmat),
-                  control = list(MCMC.burnin = 1e5))
+                  control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws)
@@ -1500,10 +1500,76 @@ test_that("BDStratTNT handles bipartite homogeneous degree bound saturation corr
                    constraints = ~bd(maxout = maxout)
                                   + blocks(attr = ~blocks_attr, levels2 = levels2)
                                   + strat(attr = ~strat_attr, pmat = pmat),
-                   control = list(MCMC.burnin = 1e5))
+                   control = list(MCMC.burnin = 1e4))
   ## check constraints
   expect_true(all(summary(nws2 ~ nodemix(~blocks_attr, levels2 = levels2)) == 0))
   el <- as.edgelist(nws2)
   degs <- tabulate(c(el), nbins = net_size)
   expect_true(all(degs <= maxout))
 })
+
+test_that("all free dyads vary with a blocks constraint", {
+  net_size <- 17
+  bip_size <- 9
+  nsim <- 200
+
+  blocks_levels_2 <- matrix(FALSE, nrow = 3, ncol = 3)
+  blocks_levels_2[1,1] <- TRUE
+  blocks_levels_2[2,3] <- TRUE
+
+  net_attrs_list <- list(list(n = net_size, directed = FALSE, bipartite = FALSE),
+                         list(n = net_size, directed = TRUE, bipartite = FALSE),
+                         list(n = net_size, directed = FALSE, bipartite = bip_size))
+
+  for (i in seq_along(net_attrs_list)) {
+    ## construct network
+    nw <- do.call(network.initialize, net_attrs_list[[i]])
+
+    ## construct logical matrix of dyads in the network
+    dyad_mat <- !diag(net_size)
+    if (is.bipartite(nw)) {
+      dyad_mat[-seq_len(bip_size),] <- FALSE
+      dyad_mat[,seq_len(bip_size)] <- FALSE
+    } else if (!is.directed(nw)) {
+      dyad_mat[lower.tri(dyad_mat)] <- FALSE
+    }
+
+    ## check dyad count
+    expect_equal(sum(dyad_mat), network.dyadcount(nw))
+
+    ## construct logical vector of free dyads in the network
+    free_dyads <- !diag(net_size)
+    free_dyads[seq_len(net_size) %% 3 == 1, seq_len(net_size) %% 3 == 1] <- FALSE
+    free_dyads[seq_len(net_size) %% 3 == 2, seq_len(net_size) %% 3 == 0] <- FALSE
+    if (!is.directed(nw) && !is.bipartite(nw)) {
+      free_dyads <- free_dyads & t(free_dyads)
+    }
+    free_dyads <- free_dyads[which(dyad_mat)]
+
+    ## restrict size of dyad_mat in bipartite case
+    if (is.bipartite(nw)) {
+      dyad_mat <- dyad_mat[seq_len(bip_size), -seq_len(bip_size)]
+    }
+
+    ## perform simulation
+    stats <- simulate(nw ~ edges,
+                      coef = c(0),
+                      monitor = ~nodemix(~seq_len(net_size), levels2 = dyad_mat),
+                      nsim = nsim,
+                      constraints = "BDStratTNT" ~ blocks(~rep(1:3, length.out = net_size),
+                                                          levels2 = blocks_levels_2),
+                      output = "stats",
+                      control = list(MCMC.burnin = 1e3, MCMC.interval = 1e3))
+
+    ## drop edges statistic
+    stats <- stats[,-1]
+
+    ## check number of stats
+    expect_equal(NCOL(stats), network.dyadcount(nw))
+
+    ## confirm that free dyads take two states and fixed dyads take one state
+    for (i in seq_len(NCOL(stats))) {
+      expect_true(length(unique(stats[, i])) == 1 + free_dyads[i])
+    }
+  }
+})
